<section id="gallery" class="py-24 bg-gray-50">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-20" data-aos="fade-up">
      <span class="inline-block text-xs uppercase tracking-widest text-gray-500 mb-3">
        {{ sections.gallery.title }}
      </span>
      <h2 class="text-3xl sm:text-4xl font-light text-gray-900 mb-4">
        Our Gallery
      </h2>
      <div class="w-16 h-px bg-gray-300 mx-auto mb-6"></div>
    </div>
    
    <div class="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
      {% for item in sections.gallery.items %}
      <div class="group bg-white border border-gray-100 overflow-hidden hover:shadow-sm transition-shadow duration-300" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="aspect-[4/3] overflow-hidden">
          <img src="{{ item.src }}" 
               alt="{{ item.alt }}" 
               class="w-full h-full object-cover group-hover:scale-105 transition-transform duration-700"
               loading="lazy">
        </div>
        
        {% if item.caption %}
        <div class="p-6">
          <h3 class="font-light text-gray-900">{{ item.caption }}</h3>
        </div>
        {% endif %}
      </div>
      {% endfor %}
    </div>
  </div>
</section>