<section id="service_features" class="py-16 bg-white">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-12" data-aos="fade-up">
      <h2 class="text-3xl md:text-4xl font-bold text-gray-900 mb-4">
        ⚡ {{ sections.service_features.title }}
      </h2>
    </div>
    
    <div class="grid md:grid-cols-3 gap-8">
      {% for item in sections.service_features.items %}
      <div class="text-center group" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="bg-white p-8 rounded-xl shadow-sm hover:shadow-md transition-shadow duration-300">
          <div class="w-12 h-12 bg-blue-600 rounded-full flex items-center justify-center mx-auto mb-6 shadow-sm group-hover:scale-110 transition-transform duration-300">
            <i class="{{ item.icon | default('ri-service-line') }} text-white text-lg"></i>
          </div>
          
          <h3 class="text-lg font-semibold text-gray-900 mb-4">{{ item.title }}</h3>
          <p class="text-gray-600 text-sm leading-relaxed">{{ item.description }}</p>
        </div>
      </div>
      {% endfor %}
    </div>
  </div>
</section>
