<section id="service_features" class="py-24 bg-white">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-20" data-aos="fade-up">
      <span class="inline-block text-xs uppercase tracking-widest text-gray-500 mb-3">
        {{ sections.service_features.title }}
      </span>
      <h2 class="text-3xl sm:text-4xl font-light text-gray-900 mb-4">
        Our Services
      </h2>
      <div class="w-16 h-px bg-gray-300 mx-auto mb-6"></div>
    </div>
    
    <div class="grid md:grid-cols-3 gap-12">
      {% for item in sections.service_features.items %}
      <div class="text-center group" data-aos="fade-up" data-aos-delay="{{ loop.index0 * 100 }}">
        <div class="bg-gray-50 p-12 border border-gray-100 hover:shadow-sm transition-shadow duration-300 h-full">
          <h3 class="text-2xl font-light text-gray-900 mb-6">{{ item.title }}</h3>
          <div class="w-8 h-px bg-gray-300 mx-auto mb-6"></div>
          <p class="text-gray-600 font-light leading-relaxed">{{ item.description }}</p>
        </div>
      </div>
      {% endfor %}
    </div>
  </div>
</section>