<section id="service_features" class="py-24 bg-gradient-to-br from-primary/5 via-white to-secondary/5">
  <div class="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-20" data-aos="zoom-in">
      <h2 class="text-5xl md:text-6xl font-black text-gray-900 mb-6">
        {{ sections.service_features.title }}
      </h2>
      <div class="w-32 h-2 bg-gradient-to-r from-primary to-secondary rounded-full mx-auto mt-8"></div>
    </div>
    
    <div class="grid md:grid-cols-3 gap-12">
      {% for item in sections.service_features.items %}
      <div class="group relative text-center" data-aos="flip-up" data-aos-delay="{{ loop.index0 * 150 }}">
        <div class="absolute -inset-4 bg-gradient-to-r from-primary/20 to-secondary/20 rounded-3xl blur-xl opacity-0 group-hover:opacity-100 transition-opacity duration-500"></div>
        
        <div class="relative bg-white p-12 rounded-3xl shadow-2xl border border-gray-100 h-full transform group-hover:scale-105 transition-all duration-500">
          <div class="relative mb-8">
            <div class="w-24 h-24 bg-gradient-to-br from-primary to-secondary rounded-3xl flex items-center justify-center mx-auto shadow-2xl group-hover:rotate-12 group-hover:scale-110 transition-all duration-500">
              <i class="{{ item.icon | default('ri-service-line') }} text-white text-3xl"></i>
            </div>
          </div>
          
          <h3 class="text-2xl font-bold text-gray-900 mb-6 group-hover:text-primary transition-colors duration-300">
            {{ item.title }}
          </h3>
          <p class="text-gray-600 leading-relaxed text-lg">{{ item.description }}</p>
        </div>
      </div>
      {% endfor %}
    </div>
  </div>
</section>