<section id="service_features" class="py-16 bg-gray-50">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-12" data-aos="fade-up">
      <h2 class="text-3xl font-bold text-gray-900 mb-4">
        {{ sections.service_features.title }}
      </h2>
      <div class="w-16 h-1 bg-primary rounded-full mx-auto mt-4"></div>
    </div>

    <div class="grid md:grid-cols-3 gap-8">
      {% for item in sections.service_features.items %}
      <div
        class="bg-white p-8 rounded-xl shadow-sm text-center hover:shadow-md transition-shadow"
        data-aos="fade-up"
        data-aos-delay="{{ loop.index0 * 100 }}"
      >
        <div
          class="w-16 h-16 bg-primary/10 rounded-full flex items-center justify-center mx-auto mb-6"
        >
          <i class="{{ item.icon }} text-primary text-2xl"></i>
        </div>

        <h3 class="text-xl font-semibold text-gray-900 mb-4">
          {{ item.title }}
        </h3>
        <p class="text-gray-600 leading-relaxed">{{ item.description }}</p>
      </div>
      {% endfor %}
    </div>
  </div>
</section>
