<section id="partners" class="py-16 bg-white">
  <div class="max-w-6xl mx-auto px-4 sm:px-6 lg:px-8">
    <div class="text-center mb-12" data-aos="fade-up">
      <h2 class="text-3xl font-bold text-gray-900 mb-4">
        {{ sections.partners.title }}
      </h2>
      {% if sections.partners.subtitle %}
      <p class="text-lg text-gray-600">{{ sections.partners.subtitle }}</p>
      {% endif %}
      <div class="w-16 h-1 bg-primary rounded-full mx-auto mt-4"></div>
    </div>

    <div
      class="grid grid-cols-2 md:grid-cols-4 lg:grid-cols-6 gap-8 items-center"
    >
      {% for partner in sections.partners.items %}
      <div
        class="flex items-center justify-center p-4 bg-gray-50 rounded-xl hover:bg-gray-100 transition-colors"
        data-aos="fade-up"
        data-aos-delay="{{ loop.index0 * 100 }}"
      >
        {% if partner.logo %}
        <img
          src="{{ partner.logo.src }}"
          alt="{{ partner.logo.alt }}"
          class="max-h-12 w-auto object-contain grayscale hover:grayscale-0 transition-all duration-300"
        />
        {% endif %}
      </div>
      {% endfor %}
    </div>
  </div>
</section>
